@@ -20,6 +20,9 @@
 from rocketmq.client import PushConsumer, ConsumeStatus
 import time
 
+from rocketmq.ffi import _CConsumeFromWhere
+
+
 def callback(msg):
     print(msg.id, msg.body,  msg.get_property('property'))
     return ConsumeStatus.CONSUME_SUCCESS
@@ -27,6 +30,7 @@ def callback(msg):
 def start_consume_message():
     consumer = PushConsumer('consumer_group')
     consumer.set_name_server_address('127.0.0.1:9876')
+    consumer.set_consume_from_where(_CConsumeFromWhere.CONSUME_FROM_LAST_OFFSET)
     consumer.subscribe('TopicTest', callback)
     print ('start consume message')
     consumer.start()
